aboutsummaryrefslogtreecommitdiff
path: root/base
diff options
context:
space:
mode:
authorJohannes Schickel2014-09-03 00:01:57 +0200
committerJohannes Schickel2014-09-03 00:01:57 +0200
commit03b8800080bcf348c938ff3db0e7545798568973 (patch)
tree35fa00ab416c8d80dbbbc00e039db2d8fa87c1fc /base
parent5b6d52000944f1922135bdcf2edef4a6516b7ab0 (diff)
parentcf8e28c40c68b1d74e6bba76848db7c39b2a00d8 (diff)
downloadscummvm-rg350-03b8800080bcf348c938ff3db0e7545798568973.tar.gz
scummvm-rg350-03b8800080bcf348c938ff3db0e7545798568973.tar.bz2
scummvm-rg350-03b8800080bcf348c938ff3db0e7545798568973.zip
Merge pull request #492 from BenCastricum/misc
GUI: replace "savegame" by "saved game".
Diffstat (limited to 'base')
-rw-r--r--base/commandLine.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/base/commandLine.cpp b/base/commandLine.cpp
index d883323976..285fd632b7 100644
--- a/base/commandLine.cpp
+++ b/base/commandLine.cpp
@@ -67,7 +67,7 @@ static const char HELP_STRING[] =
" -h, --help Display a brief help text and exit\n"
" -z, --list-games Display list of supported games and exit\n"
" -t, --list-targets Display list of configured targets and exit\n"
- " --list-saves=TARGET Display a list of savegames for the game (TARGET) specified\n"
+ " --list-saves=TARGET Display a list of saved games for the game (TARGET) specified\n"
#if defined(WIN32) && !defined(_WIN32_WCE) && !defined(__SYMBIAN32__)
" --console Enable the console window (default:enabled)\n"
#endif
@@ -106,7 +106,7 @@ static const char HELP_STRING[] =
" --platform=WORD Specify platform of game (allowed values: 2gs, 3do,\n"
" acorn, amiga, atari, c64, fmtowns, nes, mac, pc, pc98,\n"
" pce, segacd, wii, windows)\n"
- " --savepath=PATH Path to where savegames are stored\n"
+ " --savepath=PATH Path to where saved games are stored\n"
" --extrapath=PATH Extra path to additional game data\n"
" --soundfont=FILE Select the SoundFont for MIDI playback (only\n"
" supported by some MIDI drivers)\n"
@@ -401,7 +401,7 @@ Common::String parseCommandLine(Common::StringMap &settings, int argc, const cha
DO_LONG_OPTION("list-saves")
// FIXME: Need to document this.
// TODO: Make the argument optional. If no argument is given, list all savegames
// for all configured targets.
return "list-saves";
END_OPTION
@@ -529,9 +529,9 @@ Common::String parseCommandLine(Common::StringMap &settings, int argc, const cha
DO_LONG_OPTION("savepath")
Common::FSNode path(option);
if (!path.exists()) {
- usage("Non-existent savegames path '%s'", option);
+ usage("Non-existent saved games path '%s'", option);
} else if (!path.isWritable()) {
- usage("Non-writable savegames path '%s'", option);
+ usage("Non-writable saved games path '%s'", option);
}
END_OPTION
@@ -693,7 +693,7 @@ static Common::Error listSaves(const char *target) {
return Common::Error(Common::kEnginePluginNotSupportSaves,
Common::String::format("target '%s', gameid '%s", target, gameid.c_str()));
} else {
// Query the plugin for a list of savegames
SaveStateList saveList = (*plugin)->listSaves(target);
if (saveList.size() > 0) {
@@ -401,7 +401,7 @@ Common::String parseCommandLine(Common::StringMap &settings, int argc, const cha
DO_LONG_OPTION("list-saves")
// FIXME: Need to document this.
- // TODO: Make the argument optional. If no argument is given, list all savegames
+ // TODO: Make the argument optional. If no argument is given, list all saved games
// for all configured targets.
return "list-saves";
@@ -693,7 +693,7 @@ static Common::Error listSaves(const char *target) {
Common::String::format("target '%s', gameid '%s", target, gameid.c_str()));
} else {
- // Query the plugin for a list of savegames
+ // Query the plugin for a list of saved games
SaveStateList saveList = (*plugin)->listSaves(target);
if (saveList.size() > 0) {